# File: evm_VIRCAMmain.tcl
# Purpose: VIRCAM EVM main procedure
# Author: St�phane Marteau
#

# $Id: evm_VIRCAMmain.tcl 304446 2017-12-12 10:27:55Z smysore $

# Global variables
global scriptingBox
global OBdata keywordList
global compoundList compoundListObjects

# Initialization of EVM process
set version [evmInit]

# Waivers: store values for evmWaiver array also in numerical format:
foreach idx [array names evmWaiver] {

    set evmWaiver([convertRunID $idx]) $evmWaiver($idx)

}


# List of keywords to retrieve + default values to assign in the code
# when they do not exist in the given template.
set keywordList { "TEL.AG.CONFIRM" "" "TEL.AO.CONFIRM" "" \
		      "TEL.AO.PRIORITY" "" \
		      "TEL.TARG.X" "" "TEL.TARG.Y" "" \
		      "TEL.AG.START" "" "TEL.AO.START" "" \
		      "SEQ.REF.FILE1" "" "SEQ.REF.FILE2" "" \
		      "SEQ.REF.FILE3" "" "SEQ.REF.FILE4" "" \
		      "SEQ.REF.FILE5" "" "SEQ.REF.FILE6" "" \
		      "DET1.DIT" "" "DET1.NDIT" "" "INS.FILTER.NAME" "" \
		      "SEQ.NESTING" "" "SEQ.NEXPO" "" "SEQ.JITTER.MAX" "" \
		      "SEQ.JITTER.ID" "" "SEQ.JITTER.NJITTER" "" \
		      "TEL.TARG.ADDVELALPHA" "" "TEL.TARG.ADDVELDELTA" "" \
		      "SEQ.USTEP.ID" "" "TEL.ROT.OFFANGLE" "" \
		      "SEQ.TILE.ID" "" "SEQ.JITTER.SCALE" "" \
		      "SEQ.SKYOFFSET.ALPHA" "" "SEQ.SKYOFFSET.DELTA" "" \
		      "TEL.AG.GUIDESTAR" ""        \
		      "TEL.GS1.ALPHA" ""        \
		      "TEL.GS1.DELTA" ""        \
		      "OCS.EXTENDED" "" }


# Analyze selection of OBs + containers
# and parse all relevant OBs
retrieveAndParse

# Exception: if there are no OBs in the parsed material, exit
if { $OBdata(nbOBs) == 0 } { return }

# Collect Phase 1 info
collectPhase1Info

set OBdata(totalExecutionTime) 0


# Loop over all elements in the compound list
foreach object $compoundList {
	
    # Level 1 checks
    checkVIRCAMLevel1 $object

    # Level 2 checks
    checkVIRCAMLevel2 $object
    
    # Level 3 checks
    checkVIRCAMLevel3 $object

    # Level 4 checks
    checkVIRCAMLevel4 $object
}


# Check on the total allocated time

# Convert total execution time to hours
set OBdata(totalExecutionTime) [expr $OBdata(totalExecutionTime) / 3600.]

# For service mode, non-ToO runs: issue an error if the total execution time of the
# selected OBs exceeds the time allocated in the schedule

if { $Phase1data(isPublicSurvey) == 0 && $Phase1data(runMode) == "s" && \
	 $Phase1data(tooFlag) != 1 && $Phase1data(allocatedTime) > 0. && \
	 ( $OBdata(totalExecutionTime) > [expr $Phase1data(allocatedTime) * 1.03] || \
	       $OBdata(totalExecutionTime) > [expr $Phase1data(allocatedTime) + 0.25] ) } {
    
    set msg "\n******************************\n"
    append msg [format "The total execution time of the selected OB(s) exceeds the run time allocation (%.1f h) by %.1f hours.\n" $Phase1data(allocatedTime) [expr $OBdata(totalExecutionTime) - $Phase1data(allocatedTime)]]
    append msg "******************************\n\n"
    evmWarning $msg
    
}

# Display the summary table
displayEVMSummaryTable

evmInfo ""

# Display the final detailed report
displayEVMReport






